pub struct StubProvider { /* private fields */ }Expand description
Deterministic test provider that returns canned responses for all four interaction modes.
Used in unit tests, and as the default selection when
AiConfig::provider is "stub". Never performs network I/O.
Implementations